@@ -1,5 +1,4 @@
 use proc_macro::{Group, TokenStream, TokenTree};
-use std::iter::FromIterator;
 
 use super::substitution_map::SubstitutionsMap;
 
@@ -17,7 +16,12 @@ pub(super) fn perform_substitutions(
             continue;
         }
         if let Some((sub_length, sub)) = substitutions.check_subsequence(tt_iter.clone()) {
-            result.extend(sub.clone().into_iter());
+            let first_token_span = tt_iter.clone().next().unwrap().span();
+            let final_sub = sub.clone().into_iter().map(|mut tt| {
+                tt.set_span(first_token_span);
+                tt
+            });
+            result.extend(final_sub);
             to_skip = sub_length;
             continue;
         }
@@ -36,5 +40,5 @@ pub(super) fn perform_substitutions(
             break;
         }
     }
-    proc_macro::TokenStream::from_iter(result.into_iter())
+    result.into_iter().collect()
 }
